@@ -195,14 +195,35 @@ check_fit_info <- function(fit_obj) {
   if (is.null(fit_obj)) {
     rlang::abort("The `fit` module cannot be NULL.")
   }
+
+  # check required data elements
   exp_nms <- c("defaults", "func", "interface", "protect")
-  if (!isTRUE(all.equal(sort(names(fit_obj)), exp_nms))) {
+  has_req_nms <- exp_nms %in% names(fit_obj)
+
+  if (!all(has_req_nms)) {
     rlang::abort(
       glue::glue("The `fit` module should have elements: ",
       glue::glue_collapse(glue::glue("`{exp_nms}`"), sep = ", "))
       )
   }
 
+  # check optional data elements
+  opt_nms <- c("data")
+  other_nms <- setdiff(exp_nms, names(fit_obj))
+  has_opt_nms <- other_nms %in% opt_nms
+  if (any(!has_opt_nms)) {
+    msg <- glue::glue("The `fit` module can only have optional elements: ",
+                      glue::glue_collapse(glue::glue("`{exp_nms}`"), sep = ", "))
+
+    rlang::abort(msg)
+  }
+  if (any(other_nms == "data")) {
+    data_nms <- names(fit_obj$data)
+    if (length(data_nms == 0) || any(data_nms == "")) {
+      rlang::abort("All elements of the `data` argument vector must be named.")
+    }
+  }
+
   check_interface_val(fit_obj$interface)
   check_func_val(fit_obj$func)
 
@@ -302,6 +323,8 @@ check_interface_val <- function(x) {
 #'  below, depending on context.
 #' @param pre,post Optional functions for pre- and post-processing of prediction
 #'  results.
+#' @param options A list of options for engine-specific preprocessing encodings.
+#'  See Details below.
 #' @param ... Optional arguments that should be passed into the `args` slot for
 #'  prediction objects.
 #' @keywords internal
@@ -321,6 +344,36 @@ check_interface_val <- function(x) {
 #'  already been registered. `check_model_doesnt_exist()` checks the model value
 #'  and also checks to see if it is novel in the environment.
 #'
+#'  The options for engine-specific encodings dictate how the predictors should be
+#'  handled. These options ensure that the data
+#'  that `parsnip` gives to the underlying model allows for a model fit that is
+#'  as similar as possible to what it would have produced directly.
+#'
+#'  For example, if `fit()` is used to fit a model that does not have
+#'  a formula interface, typically some predictor preprocessing must
+#'  be conducted. `glmnet` is a good example of this.
+#'
+#'   There are three options that can be used for the encodings:
+#'
+#'  `predictor_indicators` describes whether and how to create indicator/dummy
+#'  variables from factor predictors. There are three options: `"none"` (do not
+#'  expand factor predictors), `"traditional"` (apply the standard
+#'  `model.matrix()` encodings), and `"one_hot"` (create the complete set
+#'  including the baseline level for all factors). This encoding only affects
+#'  cases when [fit.model_spec()] is used and the underlying model has an x/y
+#'  interface.
+#'
+#' Another option is `compute_intercept`; this controls whether `model.matrix()`
+#'  should include the intercept in its formula. This affects more than the
+#'  inclusion of an intercept column. With an intercept, `model.matrix()`
+#'  computes dummy variables for all but one factor levels. Without an
+#'  intercept, `model.matrix()` computes a full set of indicators for the
+#'  _first_ factor variable, but an incomplete set for the remainder.
+#'
+#'  Finally, the option `remove_intercept` will remove the intercept column
+#'  _after_ `model.matrix()` is finished. This can be useful if the model
+#'  function (e.g. `lm()`) automatically generates an intercept.
+#'
 #' @references "Making a parsnip model from scratch"
 #'  \url{https://tidymodels.github.io/parsnip/articles/articles/Scratch.html}
 #' @examples
@@ -759,3 +812,95 @@ pred_value_template <-  function(pre = NULL, post = NULL, func, ...) {
   list(pre = pre, post = post, func = func, args = list(...))
 }
 
+# ------------------------------------------------------------------------------
+
+check_encodings <- function(x) {
+  if (!is.list(x)) {
+    rlang::abort("`values` should be a list.")
+  }
+  req_args <- list(predictor_indicators = rlang::na_chr,
+                   compute_intercept = rlang::na_lgl,
+                   remove_intercept = rlang::na_lgl)
+
+  missing_args <- setdiff(names(req_args), names(x))
+  if (length(missing_args) > 0) {
+    rlang::abort(
+      glue::glue(
+        "The values passed to `set_encoding()` are missing arguments: ",
+        paste0("'", missing_args, "'", collapse = ", ")
+      )
+    )
+  }
+  extra_args <- setdiff(names(x), names(req_args))
+  if (length(extra_args) > 0) {
+    rlang::abort(
+      glue::glue(
+        "The values passed to `set_encoding()` had extra arguments: ",
+        paste0("'", extra_args, "'", collapse = ", ")
+      )
+    )
+  }
+  invisible(x)
+}
+
+#' @export
+#' @rdname set_new_model
+#' @keywords internal
+set_encoding <- function(model, mode, eng, options) {
+  check_model_exists(model)
+  check_eng_val(eng)
+  check_mode_val(mode)
+  check_encodings(options)
+
+  keys   <- tibble::tibble(model = model, engine = eng, mode = mode)
+  options <- tibble::as_tibble(options)
+  new_values <- dplyr::bind_cols(keys, options)
+
+
+  current_db_list <- ls(envir = get_model_env())
+  nm <- paste(model, "encoding", sep = "_")
+  if (any(current_db_list == nm)) {
+    current <- get_from_env(nm)
+    dup_check <-
+      current %>%
+      dplyr::inner_join(
+        new_values,
+        by = c("model", "engine", "mode", "predictor_indicators")
+      )
+    if (nrow(dup_check)) {
+      rlang::abort(glue::glue("Engine '{eng}' and mode '{mode}' already have defined encodings for model '{model}'."))
+    }
+
+  } else {
+    current <- NULL
+  }
+
+  db_values <- dplyr::bind_rows(current, new_values)
+  set_env_val(nm, db_values)
+
+  invisible(NULL)
+}
+
+
+#' @rdname set_new_model
+#' @keywords internal
+#' @export
+get_encoding <- function(model) {
+  check_model_exists(model)
+  nm <- paste0(model, "_encoding")
+  res <- try(get_from_env(nm), silent = TRUE)
+  if (inherits(res, "try-error")) {
+    # for objects made before encodings were specified in parsnip
+    res <-
+      get_from_env(model) %>%
+      dplyr::mutate(
+        model = model,
+        predictor_indicators = "traditional",
+        compute_intercept = TRUE,
+        remove_intercept = TRUE
+      ) %>%
+      dplyr::select(model, engine, mode, predictor_indicators,
+                    compute_intercept, remove_intercept)
+  }
+  res
+}
