@@ -19,6 +19,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "linear_reg",
+  eng = "lm",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "linear_reg",
   eng = "lm",
@@ -102,6 +113,29 @@ set_pred(
 set_model_engine("linear_reg", "regression", "glmnet")
 set_dependency("linear_reg", "glmnet", "glmnet")
 
+set_fit(
+  model = "linear_reg",
+  eng = "glmnet",
+  mode = "regression",
+  value = list(
+    interface = "matrix",
+    protect = c("x", "y", "weights"),
+    func = c(pkg = "glmnet", fun = "glmnet"),
+    defaults = list(family = "gaussian")
+  )
+)
+
+set_encoding(
+  model = "linear_reg",
+  eng = "glmnet",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_model_arg(
   model = "linear_reg",
   eng = "glmnet",
@@ -120,18 +154,6 @@ set_model_arg(
   has_submodel = FALSE
 )
 
-set_fit(
-  model = "linear_reg",
-  eng = "glmnet",
-  mode = "regression",
-  value = list(
-    interface = "matrix",
-    protect = c("x", "y", "weights"),
-    func = c(pkg = "glmnet", fun = "glmnet"),
-    defaults = list(family = "gaussian")
-  )
-)
-
 set_pred(
   model = "linear_reg",
   eng = "glmnet",
@@ -183,6 +205,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "linear_reg",
+  eng = "stan",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "linear_reg",
   eng = "stan",
@@ -287,6 +320,30 @@ set_pred(
 set_model_engine("linear_reg", "regression", "spark")
 set_dependency("linear_reg", "spark", "sparklyr")
 
+set_fit(
+  model = "linear_reg",
+  eng = "spark",
+  mode = "regression",
+  value = list(
+    interface = "formula",
+    data = c(formula = "formula", data = "x"),
+    protect = c("x", "formula", "weight_col"),
+    func = c(pkg = "sparklyr", fun = "ml_linear_regression"),
+    defaults = list()
+  )
+)
+
+set_encoding(
+  model = "linear_reg",
+  eng = "spark",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_model_arg(
   model = "linear_reg",
   eng = "spark",
@@ -305,19 +362,6 @@ set_model_arg(
   has_submodel = FALSE
 )
 
-
-set_fit(
-  model = "linear_reg",
-  eng = "spark",
-  mode = "regression",
-  value = list(
-    interface = "formula",
-    protect = c("x", "formula", "weight_col"),
-    func = c(pkg = "sparklyr", fun = "ml_linear_regression"),
-    defaults = list()
-  )
-)
-
 set_pred(
   model = "linear_reg",
   eng = "spark",
@@ -342,15 +386,6 @@ set_model_engine("linear_reg", "regression", "keras")
 set_dependency("linear_reg", "keras", "keras")
 set_dependency("linear_reg", "keras", "magrittr")
 
-set_model_arg(
-  model = "linear_reg",
-  eng = "keras",
-  parsnip = "penalty",
-  original = "penalty",
-  func = list(pkg = "dials", fun = "penalty"),
-  has_submodel = FALSE
-)
-
 set_fit(
   model = "linear_reg",
   eng = "keras",
@@ -363,6 +398,26 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "linear_reg",
+  eng = "keras",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
+set_model_arg(
+  model = "linear_reg",
+  eng = "keras",
+  parsnip = "penalty",
+  original = "penalty",
+  func = list(pkg = "dials", fun = "penalty"),
+  has_submodel = FALSE
+)
+
 set_pred(
   model = "linear_reg",
   eng = "keras",
