@@ -19,6 +19,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "logistic_reg",
+  eng = "glm",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "logistic_reg",
   eng = "glm",
@@ -121,6 +132,29 @@ set_pred(
 set_model_engine("logistic_reg", "classification", "glmnet")
 set_dependency("logistic_reg", "glmnet", "glmnet")
 
+set_fit(
+  model = "logistic_reg",
+  eng = "glmnet",
+  mode = "classification",
+  value = list(
+    interface = "matrix",
+    protect = c("x", "y", "weights"),
+    func = c(pkg = "glmnet", fun = "glmnet"),
+    defaults = list(family = "binomial")
+  )
+)
+
+set_encoding(
+  model = "logistic_reg",
+  eng = "glmnet",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_model_arg(
   model = "logistic_reg",
   eng = "glmnet",
@@ -139,19 +173,6 @@ set_model_arg(
   has_submodel = FALSE
 )
 
-set_fit(
-  model = "logistic_reg",
-  eng = "glmnet",
-  mode = "classification",
-  value = list(
-    interface = "matrix",
-    protect = c("x", "y", "weights"),
-    func = c(pkg = "glmnet", fun = "glmnet"),
-    defaults = list(family = "binomial")
-  )
-)
-
-
 set_pred(
   model = "logistic_reg",
   eng = "glmnet",
@@ -236,6 +257,7 @@ set_fit(
   mode = "classification",
   value = list(
     interface = "formula",
+    data = c(formula = "formula", data = "x"),
     protect = c("x", "formula", "weight_col"),
     func = c(pkg = "sparklyr", fun = "ml_logistic_regression"),
     defaults =
@@ -245,6 +267,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "logistic_reg",
+  eng = "spark",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "logistic_reg",
   eng = "spark",
@@ -306,6 +339,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "logistic_reg",
+  eng = "keras",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "logistic_reg",
   eng = "keras",
@@ -363,6 +407,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "logistic_reg",
+  eng = "stan",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "logistic_reg",
   eng = "stan",
