@@ -47,6 +47,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "nearest_neighbor",
+  eng = "kknn",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_fit(
   model = "nearest_neighbor",
   eng = "kknn",
@@ -59,6 +70,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "nearest_neighbor",
+  eng = "kknn",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "nearest_neighbor",
   eng = "kknn",
