@@ -29,6 +29,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "surv_reg",
+  eng = "flexsurv",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "none",
+    compute_intercept = FALSE,
+    remove_intercept = FALSE
+  )
+)
+
 set_pred(
   model = "surv_reg",
   eng = "flexsurv",
@@ -92,6 +103,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "surv_reg",
+  eng = "survival",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "none",
+    compute_intercept = FALSE,
+    remove_intercept = FALSE
+  )
+)
+
 set_pred(
   model = "surv_reg",
   eng = "survival",
