@@ -5,7 +5,8 @@ library(dplyr)
 # ------------------------------------------------------------------------------
 
 context("linear regression execution with spark")
-source("helper-objects.R")
+source(test_path("helper-objects.R"))
+hpc <- hpc_data[1:150, c(2:5, 8)]
 
 # ------------------------------------------------------------------------------
 
@@ -19,8 +20,8 @@ test_that('spark execution', {
 
   skip_if(inherits(sc, "try-error"))
 
-  iris_linreg_tr <- copy_to(sc, iris[-(1:4),   ], "iris_linreg_tr", overwrite = TRUE)
-  iris_linreg_te <- copy_to(sc, iris[  1:4 , -1], "iris_linreg_te", overwrite = TRUE)
+  hpc_linreg_tr <- copy_to(sc, hpc[-(1:4),   ], "hpc_linreg_tr", overwrite = TRUE)
+  hpc_linreg_te <- copy_to(sc, hpc[  1:4 , -1], "hpc_linreg_te", overwrite = TRUE)
 
   expect_error(
     spark_fit <-
@@ -28,7 +29,7 @@ test_that('spark execution', {
         linear_reg() %>% set_engine("spark"),
         control = ctrl,
         Sepal_Length ~ .,
-        data = iris_linreg_tr
+        data = hpc_linreg_tr
       ),
     regexp = NA
   )
@@ -37,17 +38,17 @@ test_that('spark execution', {
   expect_equal(multi_predict_args(spark_fit), NA_character_)
 
   expect_error(
-    spark_pred <- predict(spark_fit, iris_linreg_te),
+    spark_pred <- predict(spark_fit, hpc_linreg_te),
     regexp = NA
   )
 
   expect_error(
-    spark_pred_num <- predict(spark_fit, iris_linreg_te),
+    spark_pred_num <- predict(spark_fit, hpc_linreg_te),
     regexp = NA
   )
 
-  lm_fit <- lm(Sepal.Length ~ ., data = iris[-(1:4),   ])
-  lm_pred <- unname(predict(lm_fit, iris[  1:4 , -1]))
+  lm_fit <- lm(compounds ~ ., data = hpc[-(1:4),   ])
+  lm_pred <- unname(predict(lm_fit, hpc[  1:4 , -1]))
 
   expect_equal(as.data.frame(spark_pred)$pred, lm_pred)
   expect_equal(as.data.frame(spark_pred_num)$pred, lm_pred)
