@@ -2,13 +2,16 @@ library(testthat)
 library(parsnip)
 library(rlang)
 
+source(test_path("helper-objects.R"))
+hpc <- hpc_data[, c(2:5, 8)]
+
 # ------------------------------------------------------------------------------
 
 context("linear regression execution with stan")
 
-num_pred <- c("Sepal.Width", "Petal.Width", "Petal.Length")
-iris_bad_form <- as.formula(Species ~ term)
-iris_basic <- linear_reg() %>%
+num_pred <- c("compounds", "iterations", "num_pending")
+hpc_bad_form <- as.formula(class ~ term)
+hpc_basic <- linear_reg() %>%
   set_engine("stan", seed = 10, chains = 1)
 
 ctrl <- control_parsnip(verbosity = 0L, catch = FALSE)
@@ -23,18 +26,18 @@ test_that('stan_glm execution', {
 
   expect_error(
     res <- fit(
-      iris_basic,
-      Sepal.Width ~ log(Sepal.Length) + Species,
-      data = iris,
+      hpc_basic,
+      compounds ~ log(input_fields) + class,
+      data = hpc,
       control = ctrl
     ),
     regexp = NA
   )
   expect_error(
     res <- fit_xy(
-      iris_basic,
-      x = iris[, num_pred],
-      y = iris$Sepal.Length,
+      hpc_basic,
+      x = hpc[, num_pred],
+      y = hpc$input_fields,
       control = ctrl
     ),
     regexp = NA
@@ -45,9 +48,9 @@ test_that('stan_glm execution', {
 
   expect_error(
     res <- fit(
-      iris_basic,
-      Species ~ term,
-      data = iris,
+      hpc_basic,
+      class ~ term,
+      data = hpc,
       control = ctrl
     )
   )
@@ -59,28 +62,28 @@ test_that('stan prediction', {
   skip_if_not_installed("rstanarm")
   skip_on_cran()
 
-  uni_pred <- c(5.01531691055198, 4.6896592504705, 4.74907435900005, 4.82563873798984,
-                5.08044844256827)
-  inl_pred <- c(3.47062722437493, 3.38380776677489, 3.29336980560884, 3.24669710332179,
-                3.42765162180813)
+  uni_pred <- c(1691.46306020449, 1494.27323520418, 1522.36011539284, 1493.39683598195,
+                1494.93053462084)
+  inl_pred <- c(429.164145548939, 256.32488428038, 254.949927688403, 255.007333947447,
+                255.336665165556)
 
   res_xy <- fit_xy(
     linear_reg() %>%
       set_engine("stan", seed = 10, chains = 1),
-    x = iris[, num_pred],
-    y = iris$Sepal.Length,
+    x = hpc[, num_pred],
+    y = hpc$input_fields,
     control = quiet_ctrl
   )
 
-  expect_equal(uni_pred, predict(res_xy, iris[1:5, num_pred])$.pred, tolerance = 0.001)
+  expect_equal(uni_pred, predict(res_xy, hpc[1:5, num_pred])$.pred, tolerance = 0.001)
 
   res_form <- fit(
-    iris_basic,
-    Sepal.Width ~ log(Sepal.Length) + Species,
-    data = iris,
+    hpc_basic,
+    compounds ~ log(input_fields) + class,
+    data = hpc,
     control = quiet_ctrl
   )
-  expect_equal(inl_pred, predict(res_form, iris[1:5, ])$.pred, tolerance = 0.001)
+  expect_equal(inl_pred, predict(res_form, hpc[1:5, ])$.pred, tolerance = 0.001)
 })
 
 
@@ -91,32 +94,34 @@ test_that('stan intervals', {
   res_xy <- fit_xy(
     linear_reg() %>%
       set_engine("stan", seed = 1333, chains = 10, iter = 1000),
-    x = iris[, num_pred],
-    y = iris$Sepal.Length,
+    x = hpc[, num_pred],
+    y = hpc$input_fields,
     control = quiet_ctrl
   )
 
+  set.seed(1231)
   confidence_parsnip <-
     predict(res_xy,
-            new_data = iris[1:5,],
+            new_data = hpc[1:5,],
             type = "conf_int",
             level = 0.93)
 
+  set.seed(1231)
   prediction_parsnip <-
     predict(res_xy,
-            new_data = iris[1:5,],
+            new_data = hpc[1:5,],
             type = "pred_int",
             level = 0.93)
 
-  ci_lower <- c(4.93164991101342, 4.60197941230393, 4.6671442757811, 4.74402724639963,
-               4.99248110476701)
-  ci_upper <- c(5.1002837047058, 4.77617561853506, 4.83183673602725, 4.90844811805409,
-                5.16979395659009)
+  ci_lower <- c(1577.25718753727, 1382.58210286254, 1399.96490471468, 1381.56774986889,
+                1383.25519963864)
+  ci_upper <- c(1809.28331613624, 1609.11912475981, 1646.44852457781, 1608.3327281785,
+                1609.4796390366)
 
-  pi_lower <- c(4.43202758985944, 4.09957733046886, 4.17664779714598, 4.24948546338885,
-                4.50058914781073)
-  pi_upper <- c(5.59783267637042, 5.25976504318669, 5.33296516452929, 5.41050668003565,
-                5.66355828140989)
+  pi_lower <- c(-4960.33135373564, -5123.82860109357, -5063.60881734505, -5341.21637448872,
+                -5184.63627366821)
+  pi_upper <- c(8345.56815544477, 7954.98392035813, 7890.10036321417, 7970.64062851536,
+                8247.10241974192)
 
   expect_equivalent(confidence_parsnip$.pred_lower, ci_lower, tolerance = 1e-2)
   expect_equivalent(confidence_parsnip$.pred_upper, ci_upper, tolerance = 1e-2)
