@@ -7,7 +7,8 @@ library(tidyr)
 # ------------------------------------------------------------------------------
 
 context("logistic regression execution with glmnet")
-source("helper-objects.R")
+source(test_path("helper-objects.R"))
+hpc <- hpc_data[1:150, c(2:5, 8)]
 
 lending_club <- head(lending_club, 200)
 lc_form <- as.formula(Class ~ log(funded_amnt) + int_rate)
@@ -123,7 +124,7 @@ test_that('glmnet prediction, mulitiple lambda', {
 
   expect_equal(
     mult_pred,
-    multi_predict(xy_fit, lending_club[1:7, num_pred], type = "class") %>% unnest()
+    multi_predict(xy_fit, lending_club[1:7, num_pred], type = "class") %>% unnest(cols = c(.pred))
     )
 
   res_form <- fit(
@@ -152,7 +153,7 @@ test_that('glmnet prediction, mulitiple lambda', {
 
   expect_equal(
     form_pred,
-    multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")]) %>% unnest()
+    multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")]) %>% unnest(cols = c(.pred))
   )
 
 })
@@ -183,7 +184,7 @@ test_that('glmnet prediction, no lambda', {
   names(mult_pred) <- c("penalty", ".pred_class")
   mult_pred <- tibble::as_tibble(mult_pred)
 
-  expect_equal(mult_pred, multi_predict(xy_fit, lending_club[1:7, num_pred]) %>% unnest())
+  expect_equal(mult_pred, multi_predict(xy_fit, lending_club[1:7, num_pred]) %>% unnest(cols = c(.pred)))
 
   res_form <- fit(
     logistic_reg() %>% set_engine("glmnet", nlambda =  11),
@@ -211,7 +212,7 @@ test_that('glmnet prediction, no lambda', {
 
   expect_equal(
     form_pred,
-    multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")]) %>% unnest()
+    multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")]) %>% unnest(cols = c(.pred))
   )
 
 })
@@ -251,9 +252,9 @@ test_that('glmnet probabilities, one lambda', {
   form_mat <- form_mat[1:7, -1]
 
   form_pred <-
-    predict(res_form$fit,
+    unname(predict(res_form$fit,
             newx = form_mat,
-            s = 0.1, type = "response")[, 1]
+            s = 0.1, type = "response")[, 1])
   form_pred <- tibble(.pred_bad = 1 - form_pred, .pred_good = form_pred)
 
   expect_equal(
@@ -262,7 +263,7 @@ test_that('glmnet probabilities, one lambda', {
     )
 
   one_row <- predict(res_form, lending_club[1, c("funded_amnt", "int_rate")], type = "prob")
-  expect_equal(form_pred[1,], one_row)
+  expect_equivalent(form_pred[1,], one_row)
 
 })
 
@@ -296,7 +297,7 @@ test_that('glmnet probabilities, mulitiple lambda', {
   expect_equal(
     mult_pred,
     multi_predict(xy_fit, lending_club[1:7, num_pred], lambda = lams, type = "prob") %>%
-      unnest()
+      unnest(cols = c(.pred))
     )
 
   res_form <- fit(
@@ -325,7 +326,7 @@ test_that('glmnet probabilities, mulitiple lambda', {
   expect_equal(
     form_pred,
     multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")], type = "prob") %>%
-      unnest()
+      unnest(cols = c(.pred))
     )
 
 })
@@ -358,7 +359,8 @@ test_that('glmnet probabilities, no lambda', {
 
   expect_equal(
     mult_pred,
-    multi_predict(xy_fit, lending_club[1:7, num_pred], type = "prob") %>% unnest()
+    multi_predict(xy_fit, lending_club[1:7, num_pred], type = "prob") %>%
+      unnest(cols = c(.pred))
   )
 
   res_form <- fit(
@@ -386,7 +388,7 @@ test_that('glmnet probabilities, no lambda', {
 
   expect_equal(
     form_pred,
-    multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")], type = "prob") %>% unnest()
+    multi_predict(res_form, lending_club[1:7, c("funded_amnt", "int_rate")], type = "prob") %>% unnest(cols = c(.pred))
   )
 
 })
