@@ -5,11 +5,13 @@ library(rlang)
 # ------------------------------------------------------------------------------
 
 context("nearest neighbor execution with kknn")
-source("helper-objects.R")
+source(test_path("helper-objects.R"))
+hpc <- hpc_data[1:150, c(2:5, 8)]
 
-num_pred <- c("Sepal.Width", "Petal.Width", "Petal.Length")
-iris_bad_form <- as.formula(Species ~ term)
-iris_basic <- nearest_neighbor(mode = "classification",
+
+num_pred <- c("compounds", "iterations", "num_pending")
+hpc_bad_form <- as.formula(class ~ term)
+hpc_basic <- nearest_neighbor(mode = "classification",
                                neighbors = 8,
                                weight_func = "triangular") %>%
   set_engine("kknn")
@@ -25,10 +27,10 @@ test_that('kknn execution', {
   # expect no error
   expect_error(
     fit_xy(
-      iris_basic,
+      hpc_basic,
       control = ctrl,
-      x = iris[, num_pred],
-      y = iris$Sepal.Length
+      x = hpc[, num_pred],
+      y = hpc$input_fields
     ),
     regexp = "outcome should be a factor"
   )
@@ -37,10 +39,10 @@ test_that('kknn execution', {
   # expect no error
   expect_error(
     res <- fit_xy(
-      iris_basic,
+      hpc_basic,
       control = ctrl,
-      x = iris[, c("Sepal.Length", "Petal.Width")],
-      y = iris$Species
+      x = hpc[, c("input_fields", "iterations")],
+      y = hpc$class
     ),
     regexp = NA
   )
@@ -50,9 +52,9 @@ test_that('kknn execution', {
 
   expect_error(
     fit(
-      iris_basic,
-      iris_bad_form,
-      data = iris,
+      hpc_basic,
+      hpc_bad_form,
+      data = hpc,
 
       control = ctrl
     )
@@ -67,51 +69,51 @@ test_that('kknn prediction', {
 
   # continuous
   res_xy <- fit_xy(
-    iris_basic,
+    hpc_basic,
     control = ctrl,
-    x = iris[, num_pred],
-    y = iris$Species
+    x = hpc[, num_pred],
+    y = hpc$class
   )
 
   uni_pred <- predict(
     res_xy$fit,
-    newdata = iris[1:5, num_pred]
+    newdata = hpc[1:5, num_pred]
   )
 
-  expect_equal(tibble(.pred_class = uni_pred), predict(res_xy, iris[1:5, num_pred]))
+  expect_equal(tibble(.pred_class = uni_pred), predict(res_xy, hpc[1:5, num_pred]))
 
   # nominal
   res_xy_nom <- fit_xy(
-    iris_basic %>% set_mode("classification"),
+    hpc_basic %>% set_mode("classification"),
     control = ctrl,
-    x = iris[, c("Sepal.Length", "Petal.Width")],
-    y = iris$Species
+    x = hpc[, c("input_fields", "iterations")],
+    y = hpc$class
   )
 
   uni_pred_nom <- predict(
     res_xy_nom$fit,
-    newdata = iris[1:5, c("Sepal.Length", "Petal.Width")]
+    newdata = hpc[1:5, c("input_fields", "iterations")]
   )
 
   expect_equal(
     uni_pred_nom,
-    predict(res_xy_nom, iris[1:5, c("Sepal.Length", "Petal.Width")], type = "class")$.pred_class
+    predict(res_xy_nom, hpc[1:5, c("input_fields", "iterations")], type = "class")$.pred_class
   )
 
   # continuous - formula interface
   res_form <- fit(
-    iris_basic %>% set_mode("regression"),
-    Sepal.Length ~ log(Sepal.Width) + Species,
-    data = iris,
+    hpc_basic %>% set_mode("regression"),
+    input_fields ~ log(compounds) + class,
+    data = hpc,
     control = ctrl
   )
 
   form_pred <- predict(
     res_form$fit,
-    newdata = iris[1:5,]
+    newdata = hpc[1:5,]
   )
 
-  expect_equal(form_pred, predict(res_form, iris[1:5, c("Sepal.Width", "Species")])$.pred)
+  expect_equal(form_pred, predict(res_form, hpc[1:5, c("compounds", "class")])$.pred)
 })
 
 
@@ -120,23 +122,23 @@ test_that('kknn multi-predict', {
   skip_if_not_installed("kknn")
   library(kknn)
 
-  iris_te <- c(1:2, 50:51, 100:101)
+  hpc_te <- c(1:2, 50:51, 100:101)
   k_vals <- 1:10
 
   res_xy <- fit_xy(
     nearest_neighbor(mode = "classification", neighbors = 3) %>%
       set_engine("kknn"),
     control = ctrl,
-    x = iris[-iris_te, num_pred],
-    y = iris$Species[-iris_te]
+    x = hpc[-hpc_te, num_pred],
+    y = hpc$class[-hpc_te]
   )
 
-  pred_multi <- multi_predict(res_xy, iris[iris_te, num_pred], neighbors = k_vals)
+  pred_multi <- multi_predict(res_xy, hpc[hpc_te, num_pred], neighbors = k_vals)
   expect_equal(pred_multi %>% unnest(cols = c(.pred)) %>% nrow(),
-               length(iris_te) * length(k_vals))
-  expect_equal(pred_multi %>% nrow(), length(iris_te))
+               length(hpc_te) * length(k_vals))
+  expect_equal(pred_multi %>% nrow(), length(hpc_te))
 
-  pred_uni <- predict(res_xy, iris[iris_te, num_pred])
+  pred_uni <- predict(res_xy, hpc[hpc_te, num_pred])
   pred_uni_obs <-
     pred_multi %>%
     mutate(.rows = row_number()) %>%
@@ -147,13 +149,13 @@ test_that('kknn multi-predict', {
   expect_equal(pred_uni, pred_uni_obs)
 
 
-  prob_multi <- multi_predict(res_xy, iris[iris_te, num_pred],
+  prob_multi <- multi_predict(res_xy, hpc[hpc_te, num_pred],
                               neighbors = k_vals, type = "prob")
   expect_equal(prob_multi %>% unnest(cols = c(.pred)) %>% nrow(),
-               length(iris_te) * length(k_vals))
-  expect_equal(prob_multi %>% nrow(), length(iris_te))
+               length(hpc_te) * length(k_vals))
+  expect_equal(prob_multi %>% nrow(), length(hpc_te))
 
-  prob_uni <- predict(res_xy, iris[iris_te, num_pred], type = "prob")
+  prob_uni <- predict(res_xy, hpc[hpc_te, num_pred], type = "prob")
   prob_uni_obs <-
     prob_multi %>%
     mutate(.rows = row_number()) %>%
