@@ -5,7 +5,9 @@ library(rlang)
 # ------------------------------------------------------------------------------
 
 context("poly SVM")
-source("helpers.R")
+source(test_path("helpers.R"))
+source(test_path("helper-objects.R"))
+hpc <- hpc_data[1:150, c(2:5, 8)]
 
 # ------------------------------------------------------------------------------
 
@@ -17,7 +19,7 @@ test_that('primary arguments', {
     object = basic_kernlab$method$fit$args,
     expected = list(
       x = expr(missing_arg()),
-      y = expr(missing_arg()),
+      data = expr(missing_arg()),
       kernel = "rbfdot"
     )
   )
@@ -31,7 +33,7 @@ test_that('primary arguments', {
     object = rbf_sigma_kernlab$method$fit$args,
     expected = list(
       x = expr(missing_arg()),
-      y = expr(missing_arg()),
+      data = expr(missing_arg()),
       kernel = "rbfdot",
       kpar = rbf_sigma_obj
     )
@@ -47,7 +49,7 @@ test_that('engine arguments', {
     object = translate(kernlab_cv, "kernlab")$method$fit$args,
     expected = list(
       x = expr(missing_arg()),
-      y = expr(missing_arg()),
+      data = expr(missing_arg()),
       cross = new_empty_quosure(10),
       kernel = "rbfdot"
     )
@@ -110,8 +112,8 @@ test_that('svm poly regression', {
     res <- fit_xy(
       reg_mod,
       control = ctrl,
-      x = iris[,2:4],
-      y = iris$Sepal.Length
+      x = hpc[,2:4],
+      y = hpc$input_fields
     ),
     regexp = NA
   )
@@ -122,8 +124,8 @@ test_that('svm poly regression', {
   expect_error(
     fit(
       reg_mod,
-      Sepal.Length ~ .,
-      data = iris[, -5],
+      input_fields ~ .,
+      data = hpc[, -5],
       control = ctrl
     ),
     regexp = NA
@@ -136,38 +138,43 @@ test_that('svm rbf regression prediction', {
 
   skip_if_not_installed("kernlab")
 
+  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128),] %>%
+    droplevels()
+
+  ind <- c(2, 1, 143)
+
   reg_form <-
     fit(
       reg_mod,
-      Sepal.Length ~ .,
-      data = iris[, -5],
+      input_fields ~ .,
+      data = hpc[, -5],
       control = ctrl
     )
 
-  # kern_pred <-
-  #   predict(reg_form$fit, iris[1:3, -c(1, 5)]) %>%
-  #   as_tibble() %>%
-  #   setNames(".pred")
   kern_pred <-
     structure(
-      list(.pred = c(5.02786147259765, 4.81715220026091, 4.86817852816449)),
+      list(.pred = c(131.7743, 372.0932, 902.0633)),
       row.names = c(NA, -3L), class = c("tbl_df", "tbl", "data.frame"))
 
-  parsnip_pred <- predict(reg_form, iris[1:3, -c(1, 5)])
-  expect_equal(as.data.frame(kern_pred), as.data.frame(parsnip_pred))
+  parsnip_pred <- predict(reg_form, hpc[ind, -c(2, 5)])
+  expect_equal(as.data.frame(kern_pred),
+               as.data.frame(parsnip_pred),
+               tolerance = .0001)
 
 
   reg_xy_form <-
     fit_xy(
       reg_mod,
-      x = iris[, 2:4],
-      y = iris$Sepal.Length,
+      x = hpc[, c(1, 3, 4)],
+      y = hpc$input_fields,
       control = ctrl
     )
-  expect_equal(reg_form$fit, reg_xy_form$fit)
+  expect_equal(reg_form$fit@alphaindex, reg_xy_form$fit@alphaindex)
 
-  parsnip_xy_pred <- predict(reg_xy_form, iris[1:3, -c(1, 5)])
-  expect_equal(as.data.frame(kern_pred), as.data.frame(parsnip_xy_pred))
+  parsnip_xy_pred <- predict(reg_xy_form, hpc[ind, -c(2, 5)])
+  expect_equal(as.data.frame(kern_pred),
+               as.data.frame(parsnip_xy_pred),
+               tolerance = .0001)
 })
 
 # ------------------------------------------------------------------------------
@@ -176,12 +183,17 @@ test_that('svm rbf classification', {
 
   skip_if_not_installed("kernlab")
 
+  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128),] %>%
+    droplevels()
+
+  ind <- c(2, 1, 143)
+
   expect_error(
     fit_xy(
       cls_mod,
       control = ctrl,
-      x = iris[, -5],
-      y = iris$Species
+      x = hpc_no_m[, -5],
+      y = hpc_no_m$class
     ),
     regexp = NA
   )
@@ -189,8 +201,8 @@ test_that('svm rbf classification', {
   expect_error(
     fit(
       cls_mod,
-      Species ~ .,
-      data = iris,
+      class ~ .,
+      data = hpc_no_m,
       control = ctrl
     ),
     regexp = NA
@@ -203,58 +215,50 @@ test_that('svm rbf classification probabilities', {
 
   skip_if_not_installed("kernlab")
 
-  ind <- c(1, 51, 101)
+  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128),] %>%
+    droplevels()
+
+  ind <- c(4, 55, 143)
 
   set.seed(34562)
   cls_form <-
     fit(
       cls_mod,
-      Species ~ .,
-      data = iris,
+      class ~ .,
+      data = hpc_no_m,
       control = ctrl
     )
 
-  # kern_class <-
-  #   tibble(.pred_class = predict(cls_form$fit, iris[ind, -5]))
-
   kern_class <-
     structure(list(
       .pred_class = structure(
-        c(1L, 3L, 3L),
-        .Label = c("setosa", "versicolor", "virginica"), class = "factor")),
+        c(1L, 1L, 3L),
+        .Label = c("VF", "F", "L"), class = "factor")),
       row.names = c(NA, -3L), class = c("tbl_df", "tbl", "data.frame"))
 
-  parsnip_class <- predict(cls_form, iris[ind, -5])
+  parsnip_class <- predict(cls_form, hpc_no_m[ind, -5])
   expect_equal(kern_class, parsnip_class)
 
   set.seed(34562)
   cls_xy_form <-
     fit_xy(
       cls_mod,
-      x = iris[, 1:4],
-      y = iris$Species,
+      x = hpc_no_m[, 1:4],
+      y = hpc_no_m$class,
       control = ctrl
     )
-  expect_equal(cls_form$fit, cls_xy_form$fit)
+  expect_equal(cls_form$fit@alphaindex, cls_xy_form$fit@alphaindex)
 
   library(kernlab)
   kern_probs <-
-    kernlab::predict(cls_form$fit, iris[ind, -5], type = "probabilities") %>%
+    kernlab::predict(cls_form$fit, hpc_no_m[ind, -5], type = "probabilities") %>%
     as_tibble() %>%
-    setNames(c('.pred_setosa', '.pred_versicolor', '.pred_virginica'))
+    setNames(c('.pred_VF', '.pred_F', '.pred_L'))
 
-  # kern_probs <-
-  #   structure(
-  #     list(
-  #       .pred_setosa     = c(0.985403715135807, 0.0158818274678279, 0.00633995479908973),
-  #       .pred_versicolor = c(0.00818691538722139, 0.359005663318986, 0.0173471664171275),
-  #       .pred_virginica  = c(0.00640936947697121, 0.625112509213187, 0.976312878783783)),
-  #     row.names = c(NA,-3L), class = c("tbl_df", "tbl", "data.frame"))
-
-  parsnip_probs <- predict(cls_form, iris[ind, -5], type = "prob")
+  parsnip_probs <- predict(cls_form, hpc_no_m[ind, -5], type = "prob")
   expect_equal(as.data.frame(kern_probs), as.data.frame(parsnip_probs))
 
-  parsnip_xy_probs <- predict(cls_xy_form, iris[ind, -5], type = "prob")
+  parsnip_xy_probs <- predict(cls_xy_form, hpc_no_m[ind, -5], type = "prob")
   expect_equal(as.data.frame(kern_probs), as.data.frame(parsnip_xy_probs))
 })
 
